@@ -45,7 +45,7 @@ class R3sponse(object):
 		r3sponse.log(message=response["message"], log_level=log_level, save=save)
 		if django: 
 			try:
-				response = JsonResponse(response.dict(), safe=False)
+				response = JsonResponse(response.json(), safe=False)
 			except:
 				response = JsonResponse(response, safe=False)
 		return response
@@ -66,7 +66,7 @@ class R3sponse(object):
 		r3sponse.log(error=response["error"], log_level=log_level, save=save)
 		if django: 
 			try:
-				response = JsonResponse(response.dict(), safe=False)
+				response = JsonResponse(response.json(), safe=False)
 			except:
 				response = JsonResponse(response, safe=False)
 		return response
@@ -284,6 +284,7 @@ class ResponseObject(object):
 		delattr(self, key)
 	# string format.
 	def __str__(self):
+		return self.json()
 		return json.dumps(self.dict(), indent=4)
 		if isinstance(self, dict):
 			return json.dumps(self, indent=4)
